<?php

use Illuminate\Support\Facades\Route;
use Laravel\Nova\Http\Middleware\Authenticate;

Route::middleware('web')->group(fn () => [
    Route::get('/nova/phpinfo', fn () => phpinfo())
        ->middleware(Authenticate::class),
]);
