<?php

namespace Tricks\NovaPhpInformationCard;

use Illuminate\Support\ServiceProvider;
use Laravel\Nova\Events\ServingNova;
use Laravel\Nova\Nova;

class CardServiceProvider extends ServiceProvider
{
    public function boot(): void
    {
        Nova::serving(function (ServingNova $event) {
            Nova::script('opcache-status', __DIR__.'/../dist/js/card.js');
        });
        $this->loadRoutesFrom(__DIR__.'/../routes/web.php');
    }
}
