<?php

namespace Tricks\Dashboard\Tests;

use Orchestra\Testbench\TestCase as Orchestra;
use Tricks\NovaPhpInformationCard\CardServiceProvider;

class TestCase extends Orchestra
{
    protected function getPackageProviders($app): array
    {
        return [
            CardServiceProvider::class,
        ];
    }
}
