<template>
  <Card class="flex flex-col items-center justify-center">
    <div class="px-3 py-3">
      <h1>PHP <span class="text-gray-400">({{ card.php_version }})</span></h1>
        <table class="text-xl table-auto">
            <tr>
                <td class="pr-2">OPcache</td>
                <td :class="card.opcacheIsActive ? 'text-red-500' : 'text-gray-200'">{{card.opcacheIsActive ? 'enabled' : 'disabled'}}</td>
            </tr>            <tr>
                <td class="pr-2">Xdebug</td>
                <td :class="!card.xdebugIsActive ? 'text-gray-200' : 'text-green-500'">{{card.xdebugIsActive ? 'enabled' : 'disabled'}}</td>
            </tr>
        </table>
    </div>
    <a
        href="/nova/phpinfo"
    >Zeige phpinfo</a>
  </Card>
</template>

<script>
export default {
  props: ['card'],
}
</script>
