<?php

use Tricks\NovaPhpInformationCard\NovaPhpInformationCard;

test('confirm dashboard has correct attributes', function () {
    expect((new NovaPhpInformationCard())->component())->toBe('opcache-status');
});
