(()=>{"use strict";var e={744:(e,t)=>{t.Z=(e,t)=>{const r=e.__vccOpts||e;for(const[e,a]of t)r[e]=a;return r}}},t={};function r(a){var c=t[a];if(void 0!==c)return c.exports;var o=t[a]={exports:{}};return e[a](o,o.exports,r),o.exports}(()=>{const e=Vue;var t={class:"px-3 py-3"},a={class:"text-gray-400"},c={class:"text-xl table-auto"},o=(0,e.createElementVNode)("td",{class:"pr-2"},"OPcache",-1),n=(0,e.createElementVNode)("td",{class:"pr-2"},"Xdebug",-1),s=(0,e.createElementVNode)("a",{href:"/nova/phpinfo"},"Zeige phpinfo",-1);const l={props:["card"]};const d=(0,r(744).Z)(l,[["render",function(r,l,d,i,p,u){var x=(0,e.resolveComponent)("Card",!0);return(0,e.openBlock)(),(0,e.createBlock)(x,{class:"flex flex-col items-center justify-center"},{default:(0,e.withCtx)((function(){return[(0,e.createElementVNode)("div",t,[(0,e.createElementVNode)("h1",null,[(0,e.createTextVNode)("PHP "),(0,e.createElementVNode)("span",a,"("+(0,e.toDisplayString)(d.card.php_version)+")",1)]),(0,e.createElementVNode)("table",c,[(0,e.createElementVNode)("tr",null,[o,(0,e.createElementVNode)("td",{class:(0,e.normalizeClass)(d.card.opcacheIsActive?"text-red-500":"text-gray-200")},(0,e.toDisplayString)(d.card.opcacheIsActive?"enabled":"disabled"),3)]),(0,e.createTextVNode)(),(0,e.createElementVNode)("tr",null,[n,(0,e.createElementVNode)("td",{class:(0,e.normalizeClass)(d.card.xdebugIsActive?"text-green-500":"text-gray-200")},(0,e.toDisplayString)(d.card.xdebugIsActive?"enabled":"disabled"),3)])])]),s]})),_:1})}]]);Nova.booting((function(e,t){e.component("opcache-status",d)}))})()})();